@@ -2,7 +2,7 @@
 
 # construct_dt_and_classify_one_sample_case2.pl
 
-use lib '../blib/lib', '../blib/arch';
+#use lib '../blib/lib', '../blib/arch';
 
 
 ##  This script is for a mixture of symbolic and numeric features.  Since
